==> jc-1.4.0.tar.gz: javax/swing/CellRendererPane__24AccessibleCellRendererPane.h <==
// public class javax.swing.CellRendererPane$AccessibleCellRendererPane

// class file dependencies
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 3828f621b8cb1e72 javax_swing_CellRendererPane__24AccessibleCellRendererPane

// header file dependencies
// @dep_header java_awt_Container__24AccessibleAWTContainer

#include "java/awt/Container__24AccessibleAWTContainer.h"

#ifndef _JC_javax_swing_CellRendererPane__24AccessibleCellRendererPane_H_
#define _JC_javax_swing_CellRendererPane__24AccessibleCellRendererPane_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_swing_CellRendererPane$object;

// Typedefs
typedef struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$sub_refs	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$sub_refs;
typedef struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$sub_nonrefs	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$sub_nonrefs;
typedef struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$refs	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$refs;
typedef struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$nonrefs	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$nonrefs;
typedef struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$object	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$object;

typedef struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$fields_struct	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$fields_struct;
typedef const struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$vmethods	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$vmethods;
typedef const struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$vtable	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$vtable;
typedef const struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$vtype	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$vtype;

// Class fields structure
struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$fields_struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$class_fields;

// Constructors
extern void _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$method$_init$aca3d07652b597b7(_jc_env *, struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$object *, struct _jc_javax_swing_CellRendererPane$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$object *);
};

// Vtable
struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$vmethods	javax_swing_CellRendererPane__24AccessibleCellRendererPane;
};

// Vtype
struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$vtype {
	_jc_type			type;
	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$sub_refs {
	struct _jc_javax_swing_CellRendererPane$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$refs {
    _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$sub_refs	javax_swing_CellRendererPane__24AccessibleCellRendererPane;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$sub_nonrefs	javax_swing_CellRendererPane__24AccessibleCellRendererPane;
};

// Object instance structure
struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$object {
	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$vtype	*vtype;
	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$vtype _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_CellRendererPane__24AccessibleCellRendererPane, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$class_object;

#endif	/* _JC_javax_swing_CellRendererPane__24AccessibleCellRendererPane_H_ */

==> jc-1.4.5.tar.gz: javax/swing/CellRendererPane__24AccessibleCellRendererPane.h <==
// public class javax.swing.CellRendererPane$AccessibleCellRendererPane

// class file dependencies
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 8637b0b7ddec5487 javax_swing_CellRendererPane__24AccessibleCellRendererPane

// header file dependencies
// @dep_header java_awt_Container__24AccessibleAWTContainer

#include "java/awt/Container__24AccessibleAWTContainer.h"

#ifndef _JC_javax_swing_CellRendererPane__24AccessibleCellRendererPane_H_
#define _JC_javax_swing_CellRendererPane__24AccessibleCellRendererPane_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_swing_CellRendererPane$object;

// Typedefs
typedef struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$sub_refs	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$sub_refs;
typedef struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$sub_nonrefs	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$sub_nonrefs;
typedef struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$refs	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$refs;
typedef struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$nonrefs	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$nonrefs;
typedef struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$object	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$object;

typedef struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$fields_struct	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$fields_struct;
typedef const struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$vmethods	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$vmethods;
typedef const struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$vtable	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$vtable;
typedef const struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$vtype	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$vtype;

// Class fields structure
struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$fields_struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$class_fields;

// Constructors
extern void _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$method$_init$aca3d07652b597b7(_jc_env *, struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$object *, struct _jc_javax_swing_CellRendererPane$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$vmethods	javax_swing_CellRendererPane__24AccessibleCellRendererPane;
};

// Vtype
struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$vtype {
	_jc_type			type;
	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$sub_refs {
	struct _jc_javax_swing_CellRendererPane$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$refs {
    _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$sub_refs	javax_swing_CellRendererPane__24AccessibleCellRendererPane;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$sub_nonrefs	javax_swing_CellRendererPane__24AccessibleCellRendererPane;
};

// Object instance structure
struct _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$object {
	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$vtype	*vtype;
	_jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$vtype _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_CellRendererPane__24AccessibleCellRendererPane, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_CellRendererPane__24AccessibleCellRendererPane$class_object;

#endif	/* _JC_javax_swing_CellRendererPane__24AccessibleCellRendererPane_H_ */
